* [Home](https://help.sap.com/docs/)
  * [SAP LeanIX](https://help.sap.com/docs/leanix)
  * …
  * [General Modeling Guidelines](https://help.sap.com/docs/leanix/ea/general-modeling-guidelines)
  * Using Tags and Custom Fields
